@@ -198,7 +198,7 @@ const (
 	ThanosStoreCPURequets    = "100m"
 	ThanosStoreMemoryRequets = "1Gi"
 
-	MetricsCollectorCPURequets    = "100m"
+	MetricsCollectorCPURequets    = "10m"
 	MetricsCollectorMemoryRequets = "100Mi"
 	MetricsCollectorCPULimits     = ""
 	MetricsCollectorMemoryLimits  = ""
@@ -995,3 +995,11 @@ func SetOperandNames(c client.Client) error {
 
 	return nil
 }
+
+// CleanUpOperandNames delete all the operand name items
+// Should be called when the MCO CR is deleted
+func CleanUpOperandNames() {
+	for k := range operandNames {
+		delete(operandNames, k)
+	}
+}
