@@ -1,4 +1,5 @@
-// Copyright (c) 2020 Red Hat, Inc.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package patching
 
@@ -11,7 +12,7 @@ import (
 	"sigs.k8s.io/kustomize/v3/pkg/resource"
 	"sigs.k8s.io/yaml"
 
-	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
+	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/api/v1beta2"
 )
 
 var apiserver = `
@@ -51,13 +52,13 @@ func TestApplyGlobalPatches(t *testing.T) {
 	u.UnmarshalJSON(json)
 	apiserver := factory.FromMap(u.Object)
 
-	mchcr := &mcov1beta1.MultiClusterObservability{
+	mchcr := &mcov1beta2.MultiClusterObservability{
 		TypeMeta: metav1.TypeMeta{Kind: "MultiClusterObservability"},
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace:   "test",
-			Annotations: map[string]string{"mco-imageRepository": "quay.io/stolostron"},
+			Annotations: map[string]string{"mco-imageRepository": "quay.io/open-cluster-management"},
 		},
-		Spec: mcov1beta1.MultiClusterObservabilitySpec{
+		Spec: mcov1beta2.MultiClusterObservabilitySpec{
 			ImagePullPolicy: "Always",
 			ImagePullSecret: "test",
 		},
