@@ -1,4 +1,5 @@
-// Copyright (c) 2020 Red Hat, Inc.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package templates
 
@@ -18,7 +19,7 @@ import (
 	"sigs.k8s.io/kustomize/v3/pkg/resource"
 	"sigs.k8s.io/kustomize/v3/pkg/target"
 
-	mcov1beta1 "github.com/stolostron/multicluster-monitoring-operator/pkg/apis/observability/v1beta1"
+	mcov1beta2 "github.com/open-cluster-management/multicluster-observability-operator/api/v1beta2"
 )
 
 const TemplatesPathEnvVar = "TEMPLATES_PATH"
@@ -54,7 +55,7 @@ func GetTemplateRenderer() *TemplateRenderer {
 
 // GetGrafanaTemplates reads the grafana manifests
 func (r *TemplateRenderer) GetGrafanaTemplates(
-	mco *mcov1beta1.MultiClusterObservability) ([]*resource.Resource, error) {
+	mco *mcov1beta2.MultiClusterObservability) ([]*resource.Resource, error) {
 	basePath := path.Join(r.templatesPath, "base")
 	// resourceList contains all kustomize resources
 	resourceList := []*resource.Resource{}
@@ -68,21 +69,49 @@ func (r *TemplateRenderer) GetGrafanaTemplates(
 
 // GetAlertManagerTemplates reads the alertmanager manifests
 func (r *TemplateRenderer) GetAlertManagerTemplates(
-	mco *mcov1beta1.MultiClusterObservability) ([]*resource.Resource, error) {
+	mco *mcov1beta2.MultiClusterObservability) ([]*resource.Resource, error) {
 	basePath := path.Join(r.templatesPath, "base")
 	// resourceList contains all kustomize resources
 	resourceList := []*resource.Resource{}
 
-	// add grafana template
+	// add alertmanager template
 	if err := r.AddTemplateFromPath(basePath+"/alertmanager", &resourceList); err != nil {
 		return resourceList, err
 	}
 	return resourceList, nil
 }
 
+// GetThanosTemplates reads the thanos manifests
+func (r *TemplateRenderer) GetThanosTemplates(
+	mco *mcov1beta2.MultiClusterObservability) ([]*resource.Resource, error) {
+	basePath := path.Join(r.templatesPath, "base")
+	// resourceList contains all kustomize resources
+	resourceList := []*resource.Resource{}
+
+	// add thanos template
+	if err := r.AddTemplateFromPath(basePath+"/thanos", &resourceList); err != nil {
+		return resourceList, err
+	}
+	return resourceList, nil
+}
+
+// GetProxyTemplates reads the rbac-query-proxy manifests
+func (r *TemplateRenderer) GetProxyTemplates(
+	mco *mcov1beta2.MultiClusterObservability) ([]*resource.Resource, error) {
+	basePath := path.Join(r.templatesPath, "base")
+	// resourceList contains all kustomize resources
+	resourceList := []*resource.Resource{}
+
+	// add rbac-query-proxy template
+	if err := r.AddTemplateFromPath(basePath+"/proxy", &resourceList); err != nil {
+		return resourceList, err
+	}
+	return resourceList, nil
+}
+
 // GetTemplates reads base manifest
 func (r *TemplateRenderer) GetTemplates(
-	mco *mcov1beta1.MultiClusterObservability) ([]*resource.Resource, error) {
+	mco *mcov1beta2.MultiClusterObservability) ([]*resource.Resource, error) {
 	basePath := path.Join(r.templatesPath, "base")
 	// resourceList contains all kustomize resources
 	resourceList := []*resource.Resource{}
@@ -97,11 +126,6 @@ func (r *TemplateRenderer) GetTemplates(
 		return resourceList, err
 	}
 
-	// add proxy template
-	if err := r.AddTemplateFromPath(basePath+"/proxy", &resourceList); err != nil {
-		return resourceList, err
-	}
-
 	return resourceList, nil
 }
 
